@@ -1,7 +1,7 @@
 from unittest import TestCase
 from mock import patch, MagicMock
 
-import jamd_viewer
+from jamd import jamd_viewer
 import markdown_parser
 
 
@@ -10,7 +10,7 @@ class TestJamdViewer(TestCase):
         self.markdown = patch('markdown.markdown').start()
         jamd_viewer.app.testing = True
         self.client = jamd_viewer.app.test_client()
-        self.FlaskDesktopUI = patch('jamd_viewer.FlaskDesktopUI').start()
+        self.FlaskDesktopUI = patch('jamd.jamd_viewer.FlaskDesktopUI').start()
 
         self.flask_desktop_ui = MagicMock()
         self.FlaskDesktopUI.return_value = self.flask_desktop_ui
